@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: torrent
 version: 10000.0.0
-id: torrent-10000.0.0-afff942b71cfd6357d458c68678ce2f0
-key: torre_KS6qCnagWIpFoYgIULXtqV
+id: torrent-10000.0.0-39447575b4ea1e917f4f1a63eb401842
+key: torre_KFggs8GJtZ1Dq3zB2yvxea
 license: BSD3
 copyright: 2005-2007, Lemmih
 maintainer: Joey Hess <id@joeyh.name>
@@ -17,10 +17,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/torrent-10000.0.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/torrent-10000.0.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/torrent-10000.0.0
-hs-libraries: HStorrent-10000.0.0-KS6qCnagWIpFoYgIULXtqV
+hs-libraries: HStorrent-10000.0.0-KFggs8GJtZ1Dq3zB2yvxea
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bencode-0.6.0.0-e5f24bcf805f718c4b43d7a9f9a5fc93
+    bencode-0.6.0.0-14f919fcb31bcbb40f52f9f2fa9d87cf
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
